@@ -1585,12 +1585,22 @@ class IpPoolBlockSubnetDef(IpPoolSubnetDef):
             self._set_attr_if_specified(
                 body, 'ip_block_id', body_attr='ip_block_path',
                 value=ip_block_path)
+        # Attrs supported from NSX 3.0.0
         self._set_attr_if_supported(body, 'start_ip')
+        # Attrs supported from NSX 4.1.0
+        self._set_attrs_if_supported(body, ['subnet_size',
+                                            'allocation_range'])
+        # Attribute "subnet size" is replacement for "size" attribute
+        # thus, removing redundancy
+        if 'subnet_size' in body:
+            body.pop('size', None)
         return body
 
     @property
     def version_dependant_attr_map(self):
-        return {'start_ip': nsx_constants.NSX_VERSION_3_0_0}
+        return {'start_ip': nsx_constants.NSX_VERSION_3_0_0,
+                'subnet_size': nsx_constants.NSX_VERSION_4_1_0,
+                'allocation_range': nsx_constants.NSX_VERSION_4_1_0}
 
 
 class IpPoolStaticSubnetDef(IpPoolSubnetDef):
