@@ -444,6 +444,7 @@ class NsxPolicyLoadBalancerSourceIpPersistenceProfileApi(
                 if res.get('resource_type') == self.entry_def.resource_type()]
 
     def update(self, persistence_profile_id,
+               resource_type=IGNORE,
                name=IGNORE,
                description=IGNORE,
                tags=IGNORE,
@@ -454,6 +455,7 @@ class NsxPolicyLoadBalancerSourceIpPersistenceProfileApi(
                tenant=constants.POLICY_INFRA_TENANT):
         self._update(
             persistence_profile_id=persistence_profile_id,
+            resource_type=resource_type,
             name=name,
             description=description,
             tags=tags,
